@@ -32,9 +32,9 @@
 #include <klocalizedstring.h>
 #include <QDesktopServices>
 
-#include <QtCore/QTimer>
-#include <QtCore/QDir>
-#include <QtXml/qdom.h>
+#include <QTimer>
+#include <QDir>
+#include <qdom.h>
 #include <QUrlQuery>
 #include <QThreadStorage>
 
@@ -76,9 +76,9 @@ static EnginePrivate *d(const Engine* engine)
 }
 static void delete_d(const Engine* engine)
 {
-    EnginePrivate* ret = d_func()->value(engine);
-    delete ret;
-    d_func()->remove(engine);
+    if (auto d = d_func()) {
+        delete d->take(engine);
+    }
 }
 
 Engine::Engine(QObject *parent)
